# Generated by Django 3.1.12 on 2021-09-20 13:18

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="Survey",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "validators",
                    models.CharField(
                        help_text="validators are constraints that should be meet to validate a survey.",
                        max_length=50,
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                (
                    "callback",
                    models.JSONField(
                        blank=True,
                        help_text="The callback field is used to maintain callback to other apps (For example, if survey medical_record require to callback another app and pass survey response parameters)",
                        null=True,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="SurveyCategory",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=200)),
            ],
        ),
        migrations.CreateModel(
            name="SurveyQuestion",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("is_active", models.BooleanField(default=False)),
                ("title", models.CharField(max_length=200)),
                (
                    "optional_notes",
                    models.JSONField(
                        blank=True,
                        help_text="Specify the specific choice to optionally show the notes too orall choices, the user will not be required to provide a note when criteria is matches.Example ()",
                        null=True,
                    ),
                ),
                (
                    "enforced_notes",
                    models.JSONField(
                        blank=True,
                        help_text="Specify the specific choice to enforce the notes too. The user will be required to provide notes when the criteria is matchesExample ()",
                        null=True,
                    ),
                ),
                (
                    "type",
                    models.CharField(
                        choices=[
                            ("text", "Text"),
                            ("yes_no", "Yes/No"),
                            ("choice", "Choice"),
                            ("multi_choice", "Multi Choice"),
                        ],
                        default="choice",
                        max_length=100,
                    ),
                ),
                ("help_text", models.TextField(blank=True, null=True)),
                ("source", models.CharField(blank=True, max_length=200, null=True)),
            ],
        ),
        migrations.CreateModel(
            name="SurveyResponse",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                (
                    "status",
                    models.CharField(
                        choices=[("completed", "Completed"), ("partial", "Partial")],
                        max_length=10,
                    ),
                ),
                (
                    "created_by",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "survey",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="survey.survey"
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="SurveySection",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=100)),
                ("description", models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name="SurveyResponseAnswer",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("value", models.CharField(max_length=1000)),
                ("notes", models.TextField(blank=True, null=True)),
                (
                    "question",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="answers",
                        to="survey.surveyquestion",
                    ),
                ),
                (
                    "response",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="answers",
                        to="survey.surveyresponse",
                    ),
                ),
            ],
        ),
        migrations.AddField(
            model_name="surveyquestion",
            name="section",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="survey.surveysection",
            ),
        ),
        migrations.AddField(
            model_name="surveyquestion",
            name="survey",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="questions",
                to="survey.survey",
            ),
        ),
        migrations.CreateModel(
            name="SurveyChoice",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("display", models.CharField(max_length=255)),
                ("value", models.CharField(max_length=255)),
                (
                    "question",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="choices",
                        to="survey.surveyquestion",
                    ),
                ),
            ],
        ),
        migrations.AddField(
            model_name="survey",
            name="category",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE, to="survey.surveycategory"
            ),
        ),
    ]
